==> nextcloud-25.0.8.tgz: nextcloud/apps/workflowengine/l10n/ko.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "지정한 연산자가 잘못됨",
    "The given regular expression is invalid" : "지정한 정규 표현식이 잘못됨",
    "The given file size is invalid" : "지정한 파일 크기가 잘못됨",
    "The given tag id is invalid" : "지정한 태그 ID가 잘못됨",
    "The given IP range is invalid" : "지정한 IP 범위가 잘못됨",
    "The given IP range is not valid for IPv4" : "지정한 IP 범위가 올바른 IPv4가 아님",
    "The given IP range is not valid for IPv6" : "지정한 IP 범위가 올바른 IPv6이 아님",
    "The given time span is invalid" : "지정한 시간 간격이 올바르지 않음",
    "The given start time is invalid" : "지정한 시작 시간이 올바르지 않음",
    "The given end time is invalid" : "지정한 끝 시간이 올바르지 않음",
    "The given group does not exist" : "지정한 그룹이 존재히지 않음",
    "File" : "파일",
    "File created" : "파일 생성됨",
    "File updated" : "파일 업데이트됨",
    "File renamed" : "파일 이름이 변경됨",
    "File deleted" : "파일 삭제됨",
    "File accessed" : "파일 접근됨",
    "File copied" : "파일 복사됨",
    "Tag assigned" : "태그 할당됨",
    "%s created %s" : "%s이(가) %s을(를) 생성하였습니다.",
    "%s modified %s" : "%s이(가) %s을(를) 수정하였습니다.",
    "%s deleted %s" : "%s이(가) %s을(를) 삭제하였습니다.",
    "%s accessed %s" : "%s이(가) %s에 접근하였습니다.",
    "%s renamed %s" : "%s이(가) %s의 이름을 변경하였습니다.",
    "%s copied %s" : "%s이(가) %s을(를) 복사하였습니다.",
    "%s assigned %s to %s" : "%s이(가) %s을(를) %s로 할당하였습니다.",
    "Operation #%s does not exist" : "작업 #%s이(가) 존재하지 않음",
    "Entity %s does not exist" : "엔티티 %s이 없습니다",
    "Entity %s is invalid" : "엔티티 %s이 유효하지 않습니다",
    "No events are chosen." : "선택된 이벤트 없음",
    "Entity %s has no event %s" : "엔티티 %s은 이벤트 %s을 포함하지 않습니다",
    "Operation %s does not exist" : "작업 %s이(가) 존재하지 않음",
    "Operation %s is invalid" : "작업 %s이(가) 잘못됨",
    "Check %s does not exist" : "검사 %s이(가) 존재하지 않음",
    "Check %s is invalid" : "검사 %s이(가) 잘못됨",
    "Check #%s does not exist" : "검사 #%s이(가) 존재하지 않음",
    "Check %s is invalid or does not exist" : "검사 %s이(가) 올바르지 않거나 존재하지 않음",
    "Flow" : "흐름",
    "Nextcloud workflow engine" : "Nextcloud 작업 흐름 엔진",
    "Select a filter" : "필터 선택",
    "Select a file type" : "파일 타입 선택",
    "Folder" : "폴더",
    "Images" : "파일",
    "Office documents" : "오피스 문서",
    "PDF documents" : "PDF 문서",
    "Custom mimetype" : "사용자 mimetype",
    "Select a request URL" : "요청 URL 선택",
    "Files WebDAV" : "파일 WebDAV",
    "Custom URL" : "사용자 정의 URL",
    "Select a user agent" : "사용자 에이전트 지정",
    "Android client" : "Android 클라이언트",
    "iOS client" : "iOS 클라이언트",
    "Desktop client" : "데스크톱 클라이언트",
    "Thunderbird & Outlook addons" : "Thunderbird와 Outlook 확장 기능",
    "At least one event must be selected" : "적어도 하나의 이벤트는 선택해야합니다.",
    "Add new flow" : "새 흐름 추가",
    "When" : "언제",
    "and" : "그리고",
    "Cancel" : "취소",
    "Delete" : "삭제",
    "The configuration is invalid" : "설정이 잘못됨",
    "Active" : "활성화",
    "Save" : "저장",
    "Available flows" : "사용 가능한 흐름",
    "For details on how to write your own flow, check out the development documentation." : "어떻게 내 흐름을 작성하는지 자세히 알아보려면 개발자 문서를 참조하십시오.",
    "More flows" : "더 많은 흐름",
    "Browse the App Store" : "앱 스토어에서 둘러보기",
    "Show less" : "적게 보기",
    "Show more" : "더 보기",
    "Configured flows" : "설정된 흐름",
    "Your flows" : "내 흐름",
    "matches" : "일치함",
    "does not match" : "일치하지 않음",
    "is" : "맞음",
    "is not" : "아님",
    "File name" : "파일 이름",
    "File MIME type" : "파일 MIME 형식",
    "File size (upload)" : "파일 크기(업로드)",
    "less" : "작음",
    "less or equals" : "작거나 같음",
    "greater or equals" : "크거나 같음",
    "greater" : "큼",
    "Request remote address" : "요청의 원격 주소",
    "matches IPv4" : "IPv4와 일치함",
    "does not match IPv4" : "IPv4와 일치하지 않음",
    "matches IPv6" : "IPv6과 일치함",
    "does not match IPv6" : "IPv6과 일치하지 않음",
    "File system tag" : "파일 시스템 태그",
    "is tagged with" : "다음으로 태그됨",
    "is not tagged with" : "다음으로 태그되지 않음",
    "Request URL" : "요청 URL",
    "Request time" : "요청 시간",
    "between" : "사이",
    "not between" : "사이에 없음",
    "Request user agent" : "요청 사용자 에이전트",
    "User group membership" : "사용자 그룹 구성원",
    "is member of" : "구성원임",
    "is not member of" : "구성원이 아님",
    "Predefined URLs" : "사전 정의된 URL",
    "Others" : "기타"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.5.tgz: nextcloud/apps/workflowengine/l10n/ko.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "지정한 연산자가 잘못됨",
    "The given regular expression is invalid" : "지정한 정규 표현식이 잘못됨",
    "The given file size is invalid" : "지정한 파일 크기가 잘못됨",
    "The given tag id is invalid" : "지정한 태그 ID가 잘못됨",
    "The given IP range is invalid" : "지정한 IP 범위가 잘못됨",
    "The given IP range is not valid for IPv4" : "지정한 IP 범위가 올바른 IPv4가 아님",
    "The given IP range is not valid for IPv6" : "지정한 IP 범위가 올바른 IPv6이 아님",
    "The given time span is invalid" : "지정한 시간 간격이 올바르지 않음",
    "The given start time is invalid" : "지정한 시작 시간이 올바르지 않음",
    "The given end time is invalid" : "지정한 끝 시간이 올바르지 않음",
    "The given group does not exist" : "지정한 그룹이 존재히지 않음",
    "File" : "파일",
    "File created" : "파일 생성됨",
    "File updated" : "파일 업데이트됨",
    "File renamed" : "파일 이름이 변경됨",
    "File deleted" : "파일 삭제됨",
    "File accessed" : "파일 접근됨",
    "File copied" : "파일 복사됨",
    "Tag assigned" : "태그 할당됨",
    "%s created %s" : "%s님이 %s을(를) 생성함",
    "%s modified %s" : "%s님이 %s을(를) 수정함",
    "%s deleted %s" : "%s님이 %s을(를) 삭제함",
    "%s accessed %s" : "%s님이 %s에 접근함",
    "%s renamed %s" : "%s님이 %s의 이름을 변경함",
    "%s copied %s" : "%s님이 %s을(를) 복사함",
    "%s assigned %s to %s" : "%s님이 %s을(를) %s(으)로 할당함",
    "Operation #%s does not exist" : "작업 #%s이(가) 존재하지 않음",
    "Entity %s does not exist" : "엔티티 %s이 없습니다.",
    "Entity %s is invalid" : "엔티티 %s이 유효하지 않습니다.",
    "No events are chosen." : "선택된 이벤트 없음",
    "Entity %s has no event %s" : "엔티티 %s은 이벤트 %s을 포함하지 않습니다.",
    "Operation %s does not exist" : "작업 %s이(가) 존재하지 않음",
    "Operation %s is invalid" : "작업 %s이(가) 잘못됨",
    "Check %s does not exist" : "검사 %s이(가) 존재하지 않음",
    "Check %s is invalid" : "검사 %s이(가) 잘못됨",
    "Check #%s does not exist" : "검사 #%s이(가) 존재하지 않음",
    "Check %s is invalid or does not exist" : "검사 %s이(가) 올바르지 않거나 존재하지 않음",
    "Flow" : "흐름",
    "Nextcloud workflow engine" : "Nextcloud 작업 흐름 엔진",
    "Select a filter" : "필터 선택",
    "Select a file type" : "파일 타입 선택",
    "Folder" : "폴더",
    "Images" : "파일",
    "Office documents" : "오피스 문서",
    "PDF documents" : "PDF 문서",
    "Custom mimetype" : "사용자 mimetype",
    "Select a request URL" : "요청 URL 선택",
    "Files WebDAV" : "파일 WebDAV",
    "Custom URL" : "사용자 정의 URL",
    "Select a user agent" : "사용자 에이전트 지정",
    "Android client" : "Android 클라이언트",
    "iOS client" : "iOS 클라이언트",
    "Desktop client" : "데스크톱 클라이언트",
    "Thunderbird & Outlook addons" : "Thunderbird와 Outlook 확장 기능",
    "At least one event must be selected" : "적어도 하나의 이벤트는 선택해야합니다.",
    "Add new flow" : "새 흐름 추가",
    "When" : "언제",
    "and" : "그리고",
    "Cancel" : "취소",
    "Delete" : "삭제",
    "The configuration is invalid" : "설정이 잘못됨",
    "Active" : "활성화",
    "Save" : "저장",
    "Available flows" : "사용 가능한 흐름",
    "For details on how to write your own flow, check out the development documentation." : "어떻게 내 흐름을 작성하는지 자세히 알아보려면 개발자 문서를 참조하십시오.",
    "More flows" : "더 많은 흐름",
    "Browse the App Store" : "앱 스토어에서 둘러보기",
    "Show less" : "적게 보기",
    "Show more" : "더 보기",
    "Configured flows" : "설정된 흐름",
    "Your flows" : "내 흐름",
    "matches" : "일치함",
    "does not match" : "일치하지 않음",
    "is" : "맞음",
    "is not" : "아님",
    "File name" : "파일 이름",
    "File MIME type" : "파일 MIME 형식",
    "File size (upload)" : "파일 크기(업로드)",
    "less" : "작음",
    "less or equals" : "작거나 같음",
    "greater or equals" : "크거나 같음",
    "greater" : "큼",
    "Request remote address" : "요청의 원격 주소",
    "matches IPv4" : "IPv4와 일치함",
    "does not match IPv4" : "IPv4와 일치하지 않음",
    "matches IPv6" : "IPv6과 일치함",
    "does not match IPv6" : "IPv6과 일치하지 않음",
    "File system tag" : "파일 시스템 태그",
    "is tagged with" : "다음으로 태그됨",
    "is not tagged with" : "다음으로 태그되지 않음",
    "Request URL" : "요청 URL",
    "Request time" : "요청 시간",
    "between" : "사이",
    "not between" : "사이에 없음",
    "Request user agent" : "요청 사용자 에이전트",
    "User group membership" : "사용자 그룹 구성원",
    "is member of" : "구성원임",
    "is not member of" : "구성원이 아님"
},
"nplurals=1; plural=0;");
